@@ -80,7 +80,7 @@ $Data::Dumper::Useqq    = 1;
     }
 }
 
-my $v_offset     = '0.21';
+my $v_offset     = '0.23';
 my $mod_version  = $Locales::VERSION - $v_offset;
 my $cldr_version = $Locales::cldr_version;
 my $cldr_db_path;
@@ -560,6 +560,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::Language::$tag\::VERSION = '$mod_version';
 
@@ -595,6 +596,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::Territory::$tag\::VERSION = '$mod_version';
 
@@ -820,6 +822,14 @@ sub write_native_module {
     my $code_to_name_str    = _stringify_hash_no_dumper($native_map);
     my $fallback_lookup_str = _stringify_hash_no_dumper($fallback_lookup);
 
+    # nerd alert! TODO: verify during next build
+    if ( $code_to_name_str->{'tlh'} eq 'Klingon' ) {    # i.e. no CLDR data for tlh
+
+        # "\x{f8e4}\x{f8d7}\x{f8dc}\x{f8d0}\x{f8db}"
+        # "\xef\xa3\xa4\xef\xa3\x97\xef\xa3\x9c\xef\xa3\x90\xef\xa3\x9b"
+        $code_to_name_str->{'tlh'} = "";    # need a font to see this, like Bengali
+    }
+
     _write_utf8_perl(
         "$locales_db/Native.pm", qq{package Locales::DB::Native;
 
@@ -827,6 +837,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::Native::VERSION = '$mod_version';
 
@@ -873,6 +884,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::Loadable::VERSION = '$mod_version';
 
@@ -905,6 +917,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::CharacterOrientation::VERSION = '$mod_version';
 
@@ -942,6 +955,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::CharacterOrientation::Tiny::VERSION = '$mod_version';
 
@@ -984,6 +998,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::LocaleDisplayPattern::VERSION = '$mod_version';
 
@@ -1026,6 +1041,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::LocaleDisplayPattern::Tiny::VERSION = '$mod_version';
 
@@ -1088,6 +1104,7 @@ use strict;
 use warnings;
 
 # Auto generated from CLDR
+use if \$Locales::_UNICODE_STRINGS, 'utf8';
 
 \$Locales::DB::Docs::PluralForms::VERSION = '$mod_version';
 
